@@ -36,7 +36,6 @@ func TestDestroy_2(t *testing.T) {
 		wantDeletes := tc.deleted
 
 		var helm = &exectest.Helm{
-			Helm3:                true,
 			FailOnUnexpectedList: true,
 			FailOnUnexpectedDiff: true,
 			Lists:                tc.lists,
@@ -55,11 +54,12 @@ func TestDestroy_2(t *testing.T) {
 			}
 
 			app := appWithFs(&App{
-				OverrideHelmBinary:  DefaultHelmBinary,
-				fs:                  ffs.DefaultFileSystem(),
-				OverrideKubeContext: "",
-				Env:                 "default",
-				Logger:              logger,
+				OverrideHelmBinary:              DefaultHelmBinary,
+				fs:                              ffs.DefaultFileSystem(),
+				OverrideKubeContext:             "",
+				DisableKubeVersionAutoDetection: true,
+				Env:                             "default",
+				Logger:                          logger,
 				helms: map[helmKey]helmexec.Interface{
 					createHelmKey("helm", ""): helm,
 				},
