@@ -795,7 +795,6 @@ releases:
 				DiffMutex:            &sync.Mutex{},
 				ChartsMutex:          &sync.Mutex{},
 				ReleasesMutex:        &sync.Mutex{},
-				Helm3:                true,
 			}
 
 			bs := runWithLogCapture(t, "debug", func(t *testing.T, logger *zap.SugaredLogger) {
@@ -807,11 +806,12 @@ releases:
 				}
 
 				app := appWithFs(&App{
-					OverrideHelmBinary:  DefaultHelmBinary,
-					fs:                  ffs.DefaultFileSystem(),
-					OverrideKubeContext: "",
-					Env:                 "default",
-					Logger:              logger,
+					OverrideHelmBinary:              DefaultHelmBinary,
+					fs:                              ffs.DefaultFileSystem(),
+					OverrideKubeContext:             "",
+					DisableKubeVersionAutoDetection: true,
+					Env:                             "default",
+					Logger:                          logger,
 					helms: map[helmKey]helmexec.Interface{
 						createHelmKey("helm", ""): helm,
 					},
