@@ -16,37 +16,38 @@ import (
 )
 
 type diffConfig struct {
-	args                    string
-	diffArgs                string
-	values                  []string
-	retainValuesFiles       bool
-	set                     []string
-	validate                bool
-	skipCRDs                bool
-	skipDeps                bool
-	skipRefresh             bool
-	includeTests            bool
-	skipNeeds               bool
-	includeNeeds            bool
-	includeTransitiveNeeds  bool
-	suppress                []string
-	suppressSecrets         bool
-	showSecrets             bool
-	noHooks                 bool
-	suppressDiff            bool
-	suppressOutputLineRegex []string
-	noColor                 bool
-	context                 int
-	diffOutput              string
-	concurrency             int
-	detailedExitcode        bool
-	stripTrailingCR         bool
-	interactive             bool
-	skipDiffOnInstall       bool
-	skipSchemaValidation    bool
-	reuseValues             bool
-	logger                  *zap.SugaredLogger
-	takeOwnership           bool
+	args                     string
+	diffArgs                 string
+	values                   []string
+	retainValuesFiles        bool
+	set                      []string
+	validate                 bool
+	skipCRDs                 bool
+	skipDeps                 bool
+	skipRefresh              bool
+	includeTests             bool
+	skipNeeds                bool
+	includeNeeds             bool
+	includeTransitiveNeeds   bool
+	suppress                 []string
+	suppressSecrets          bool
+	showSecrets              bool
+	noHooks                  bool
+	suppressDiff             bool
+	suppressOutputLineRegex  []string
+	noColor                  bool
+	context                  int
+	diffOutput               string
+	concurrency              int
+	detailedExitcode         bool
+	stripTrailingCR          bool
+	interactive              bool
+	skipDiffOnInstall        bool
+	skipSchemaValidation     bool
+	reuseValues              bool
+	logger                   *zap.SugaredLogger
+	takeOwnership            bool
+	enforceNeedsAreInstalled bool
 }
 
 func (a diffConfig) Args() string {
@@ -188,6 +189,10 @@ func (a diffConfig) TakeOwnership() bool {
 	return a.takeOwnership
 }
 
+func (a diffConfig) EnforceNeedsAreInstalled() bool {
+	return a.enforceNeedsAreInstalled
+}
+
 func TestDiff(t *testing.T) {
 	type flags struct {
 		skipNeeds    bool
@@ -1149,7 +1154,6 @@ releases:
 				DiffMutex:            &sync.Mutex{},
 				ChartsMutex:          &sync.Mutex{},
 				ReleasesMutex:        &sync.Mutex{},
-				Helm3:                true,
 			}
 
 			bs := runWithLogCapture(t, "debug", func(t *testing.T, logger *zap.SugaredLogger) {
@@ -1166,11 +1170,12 @@ releases:
 				}
 
 				app := appWithFs(&App{
-					OverrideHelmBinary:  DefaultHelmBinary,
-					fs:                  ffs.DefaultFileSystem(),
-					OverrideKubeContext: overrideKubeContext,
-					Env:                 "default",
-					Logger:              logger,
+					OverrideHelmBinary:              DefaultHelmBinary,
+					fs:                              ffs.DefaultFileSystem(),
+					OverrideKubeContext:             overrideKubeContext,
+					DisableKubeVersionAutoDetection: true,
+					Env:                             "default",
+					Logger:                          logger,
 					helms: map[helmKey]helmexec.Interface{
 						createHelmKey("helm", overrideKubeContext): helm,
 					},
