@@ -1,21 +1,23 @@
 package config
 
 import (
+	"regexp"
 	"strings"
 
 	"github.com/helmfile/helmfile/pkg/maputil"
 )
 
 func NewCLIConfigImpl(g *GlobalImpl) error {
+	re := regexp.MustCompile(`(?:,|^)([^\s=]+)=(['"][^'"]*['"]|[^,]+)`)
 	optsSet := g.RawStateValuesSetString()
 	if len(optsSet) > 0 {
 		set := map[string]any{}
 		for i := range optsSet {
-			ops := strings.Split(optsSet[i], ",")
+			ops := re.FindAllStringSubmatch(optsSet[i], -1)
 			for j := range ops {
-				op := strings.SplitN(ops[j], "=", 2)
-				k := maputil.ParseKey(op[0])
-				v := op[1]
+				op := ops[j]
+				k := maputil.ParseKey(op[1])
+				v := op[2]
 
 				maputil.Set(set, k, v, true)
 			}
