@@ -16,6 +16,8 @@ type SyncOptions struct {
 	IncludeNeeds bool
 	// IncludeTransitiveNeeds is the include transitive needs flag
 	IncludeTransitiveNeeds bool
+	// EnforceNeedsAreInstalled indicates whether to error when there are unmeetable dependencies
+	EnforceNeedsAreInstalled bool
 	// SkipCrds is the skip crds flag
 	SkipCRDs bool
 	// Wait is the wait flag
@@ -82,6 +84,11 @@ func (t *SyncImpl) IncludeTransitiveNeeds() bool {
 	return t.SyncOptions.IncludeTransitiveNeeds
 }
 
+// EnforceNeedsAreInstalled errors if the transitive dependencies are not installable
+func (t *SyncImpl) EnforceNeedsAreInstalled() bool {
+	return t.SyncOptions.EnforceNeedsAreInstalled
+}
+
 // Set returns the Set
 func (t *SyncImpl) Set() []string {
 	return t.SyncOptions.Set
