@@ -243,7 +243,68 @@ func MergeMaps(a, b map[string]interface{}) map[string]interface{} {
 				}
 			}
 		}
+		// Handle array merging element-by-element
+		vSlice := toInterfaceSlice(v)
+		if vSlice != nil {
+			if outVal, exists := out[k]; exists {
+				outSlice := toInterfaceSlice(outVal)
+				if outSlice != nil {
+					// Both are slices - merge element by element
+					out[k] = mergeSlices(outSlice, vSlice)
+					continue
+				}
+			}
+		}
 		out[k] = v
 	}
 	return out
 }
+
+// toInterfaceSlice converts various slice types to []interface{}
+func toInterfaceSlice(v any) []any {
+	if slice, ok := v.([]any); ok {
+		return slice
+	}
+	return nil
+}
+
+// mergeSlices merges two slices element by element
+// Elements from override (b) take precedence, but we preserve elements from base (a)
+// that don't exist in override
+func mergeSlices(base, override []any) []any {
+	// Determine the maximum length
+	maxLen := len(base)
+	if len(override) > maxLen {
+		maxLen = len(override)
+	}
+
+	result := make([]interface{}, maxLen)
+
+	// First copy all elements from base
+	copy(result, base)
+
+	// Then merge/override with elements from override
+	for i := 0; i < len(override); i++ {
+		overrideVal := override[i]
+
+		// Skip nil values in override - they represent unset indices
+		if overrideVal == nil {
+			continue
+		}
+
+		// If both are maps, merge them recursively
+		if overrideMap, ok := overrideVal.(map[string]any); ok {
+			if i < len(base) {
+				if baseMap, ok := base[i].(map[string]any); ok {
+					result[i] = MergeMaps(baseMap, overrideMap)
+					continue
+				}
+			}
+		}
+
+		// Otherwise, override completely
+		result[i] = overrideVal
+	}
+
+	return result
+}
