@@ -358,11 +358,11 @@ func testFromYaml(t *testing.T, GoYamlV3 bool) {
 }
 
 func TestFromYaml(t *testing.T) {
-	t.Run("with gopkg.in/yaml.v2", func(t *testing.T) {
+	t.Run("with go.yaml.in/yaml/v2", func(t *testing.T) {
 		testFromYaml(t, true)
 	})
 
-	t.Run("with gopkg.in/yaml.v3", func(t *testing.T) {
+	t.Run("with go.yaml.in/yaml/v3", func(t *testing.T) {
 		testFromYaml(t, false)
 	})
 }
